@@ -10,11 +10,12 @@ from typing import Iterable
 from .sql_container import SqlContainer
 from .sql_enum import SqlEnum
 from .sql_val import SqlVal
+from .utils.classes.container_convertible import ContainerConvertible
 from .utils.classes.string_convertible import StringConvertible
 from .utils.classes.special_convertion_requier import SpecialConvertionRequier
 
 
-class SqlVals(SqlEnum, StringConvertible, SpecialConvertionRequier):
+class SqlVals(SqlEnum, StringConvertible, SpecialConvertionRequier, ContainerConvertible):
     """
     SqlVals class is invented for better experience to convert python values to sql strings.
     """
@@ -34,8 +35,8 @@ class SqlVals(SqlEnum, StringConvertible, SpecialConvertionRequier):
         """Get multiline representation"""
         return SqlContainer(',\n'.join(get_values(self)))
 
-    def copy(self, /):
-        return SqlVals(list(self.list))
+    def copy(self):
+        return SqlVals(*self.data.copy())
 
 
 def get_values(iterable: Iterable):
